dummy-yummy
===========

dummy-yummy is a dummy package used for testing automatic installation in virtualenvs with [3bot](https://github.com/3bot/3bot) and continous integration with [3bot-hooks](https://github.com/3bot/3bot-hook).
